Example notebooks
=================

.. _example_notebooks_section:

This section contains several examples for generating, manipulating and analyzing arrays and designs using the Orthogonal Arrays package. The examples are shown using Jupyter notebooks, which can be found on github https://github.com/eendebakpt/oapackage/tree/master/docs/examples.

.. toctree::
    :caption: List of example notebooks
    :maxdepth: 3
    :titlesonly:
    :glob:

    examples/example_oapackage.ipynb
    examples/example_designs.ipynb
    examples/example_oa_files.ipynb
    examples/example_design_generation.ipynb
    examples/example_optimal_orthogonal_arrays.ipynb
    examples/example_generation_optimal_designs.ipynb
    examples/example_nauty.ipynb
    examples/example_*
    examples/conference_design*
